Index: src/gpu/GrBatchTest.h |
diff --git a/src/gpu/GrBatchTest.h b/src/gpu/GrBatchTest.h |
index 9daa9609ce784c72aca334eb3d22d4e2c1132d31..32e8e28930e64e2cd4a1f092149e76f00a195bb6 100644 |
--- a/src/gpu/GrBatchTest.h |
+++ b/src/gpu/GrBatchTest.h |
@@ -12,7 +12,7 @@ |
#ifdef GR_TEST_UTILS |
-class GrBatch; |
+class GrDrawBatch; |
class GrContext; |
class SkRandom; |
@@ -21,19 +21,19 @@ class SkRandom; |
* are generally useful for GrBatch testing |
*/ |
-// Batches should define test functions using BATCH_TEST_DEFINE. The other macros defined below |
-// are used exclusively by the test harness. |
-typedef GrBatch* (*BatchTestFunc)(SkRandom* random, GrContext* context); |
-#define BATCH_TEST_DEFINE(Batch) \ |
- GrBatch* Batch##__Test(SkRandom* random, GrContext* context) |
-#define BATCH_TEST_EXTERN(Batch) \ |
- extern GrBatch* Batch##__Test(SkRandom*, GrContext* context); |
-#define BATCH_TEST_ENTRY(Batch) \ |
+// Batches should define test functions using DRAW_BATCH_TEST_DEFINE. The other macros defined |
+// below are used exclusively by the test harness. |
+typedef GrDrawBatch* (*BatchTestFunc)(SkRandom* random, GrContext* context); |
+#define DRAW_BATCH_TEST_DEFINE(Batch) \ |
+ GrDrawBatch* Batch##__Test(SkRandom* random, GrContext* context) |
+#define DRAW_BATCH_TEST_EXTERN(Batch) \ |
+ extern GrDrawBatch* Batch##__Test(SkRandom*, GrContext* context); |
+#define DRAW_BATCH_TEST_ENTRY(Batch) \ |
Batch##__Test |
-#define BATCH_TEST_FRIEND(Batch) \ |
- friend GrBatch* Batch##__Test(SkRandom* random, GrContext* context); |
+#define DRAW_BATCH_TEST_FRIEND(Batch) \ |
+ friend GrDrawBatch* Batch##__Test(SkRandom* random, GrContext* context); |
-GrBatch* GrRandomBatch(SkRandom*, GrContext*); |
+GrDrawBatch* GrRandomDrawBatch(SkRandom*, GrContext*); |
#endif |
#endif |